Class: Google::Cloud::ManagedKafka::V1::Acl

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/v1/resources.rb

Overview

Represents the set of ACLs for a given Kafka Resource Pattern, which consists of resource_type, resource_name and pattern_type.

Instance Attribute Summary collapse

Instance Attribute Details

#acl_entries::Array<::Google::Cloud::ManagedKafka::V1::AclEntry>

Returns Required. The ACL entries that apply to the resource pattern. The maximum number of allowed entries 100.

Returns:



603
604
605
606
# File 'proto_docs/google/cloud/managedkafka/v1/resources.rb', line 603

class Acl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#etag::String

Returns Optional. etag is used for concurrency control. An etag is returned in the response to GetAcl and CreateAcl. Callers are required to put that etag in the request to UpdateAcl to ensure that their change will be applied to the same version of the acl that exists in the Kafka Cluster.

A terminal 'T' character in the etag indicates that the AclEntries were truncated; more entries for the Acl exist on the Kafka Cluster, but can't be returned in the Acl due to repeated field limits.

Returns:

  • (::String)

    Optional. etag is used for concurrency control. An etag is returned in the response to GetAcl and CreateAcl. Callers are required to put that etag in the request to UpdateAcl to ensure that their change will be applied to the same version of the acl that exists in the Kafka Cluster.

    A terminal 'T' character in the etag indicates that the AclEntries were truncated; more entries for the Acl exist on the Kafka Cluster, but can't be returned in the Acl due to repeated field limits.



603
604
605
606
# File 'proto_docs/google/cloud/managedkafka/v1/resources.rb', line 603

class Acl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The name for the acl. Represents a single Resource Pattern. Structured like: projects/{project}/locations/{location}/clusters/{cluster}/acls/{acl_id}

The structure of acl_id defines the Resource Pattern (resource_type, resource_name, pattern_type) of the acl. acl_id is structured like one of the following:

For acls on the cluster: cluster

For acls on a single resource within the cluster: topic/{resource_name} consumerGroup/{resource_name} transactionalId/{resource_name}

For acls on all resources that match a prefix: topicPrefixed/{resource_name} consumerGroupPrefixed/{resource_name} transactionalIdPrefixed/{resource_name}

For acls on all resources of a given type (i.e. the wildcard literal ""): allTopics (represents `topic/) allConsumerGroups(representsconsumerGroup/) allTransactionalIds(representstransactionalId/`).

Returns:

  • (::String)

    Identifier. The name for the acl. Represents a single Resource Pattern. Structured like: projects/{project}/locations/{location}/clusters/{cluster}/acls/{acl_id}

    The structure of acl_id defines the Resource Pattern (resource_type, resource_name, pattern_type) of the acl. acl_id is structured like one of the following:

    For acls on the cluster: cluster

    For acls on a single resource within the cluster: topic/{resource_name} consumerGroup/{resource_name} transactionalId/{resource_name}

    For acls on all resources that match a prefix: topicPrefixed/{resource_name} consumerGroupPrefixed/{resource_name} transactionalIdPrefixed/{resource_name}

    For acls on all resources of a given type (i.e. the wildcard literal ""): allTopics (represents `topic/) allConsumerGroups(representsconsumerGroup/) allTransactionalIds(representstransactionalId/`)



603
604
605
606
# File 'proto_docs/google/cloud/managedkafka/v1/resources.rb', line 603

class Acl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pattern_type::String (readonly)

Returns Output only. The ACL pattern type derived from the name. One of: LITERAL, PREFIXED.

Returns:

  • (::String)

    Output only. The ACL pattern type derived from the name. One of: LITERAL, PREFIXED.



603
604
605
606
# File 'proto_docs/google/cloud/managedkafka/v1/resources.rb', line 603

class Acl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_name::String (readonly)

Returns Output only. The ACL resource name derived from the name. For cluster resource_type, this is always "kafka-cluster". Can be the wildcard literal "*".

Returns:

  • (::String)

    Output only. The ACL resource name derived from the name. For cluster resource_type, this is always "kafka-cluster". Can be the wildcard literal "*".



603
604
605
606
# File 'proto_docs/google/cloud/managedkafka/v1/resources.rb', line 603

class Acl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_type::String (readonly)

Returns Output only. The ACL resource type derived from the name. One of: CLUSTER, TOPIC, GROUP, TRANSACTIONAL_ID.

Returns:

  • (::String)

    Output only. The ACL resource type derived from the name. One of: CLUSTER, TOPIC, GROUP, TRANSACTIONAL_ID.



603
604
605
606
# File 'proto_docs/google/cloud/managedkafka/v1/resources.rb', line 603

class Acl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end