Class: Google::Cloud::ManagedKafka::V1::TrustConfig::CertificateAuthorityServiceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::ManagedKafka::V1::TrustConfig::CertificateAuthorityServiceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/managedkafka/v1/resources.rb
Overview
A configuration for the Google Certificate Authority Service.
Instance Attribute Summary collapse
-
#ca_pool ⇒ ::String
Required.
Instance Attribute Details
#ca_pool ⇒ ::String
Returns Required. The name of the CA pool to pull CA certificates from. Structured like: projects/{project}/locations/{location}/caPools/{ca_pool}. The CA pool does not need to be in the same project or location as the Kafka cluster.
207 208 209 210 |
# File 'proto_docs/google/cloud/managedkafka/v1/resources.rb', line 207 class CertificateAuthorityServiceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |